pub enum ModifierScheme {
Mac,
Pc,
}Expand description
How the abstract modifier roles of an Accel map onto the physical
modifier keys of Modifiers. See the module docs for the table.
Variants
Mac
primary is the Command (logo) key, secondary the Control key.
Pc
primary is the Control key, secondary the Super / Windows (logo)
key. Used everywhere but macOS.
Implementations